@@ -11,22 +11,22 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: config.h,v 1.42.4.1 2008/11/02 14:30:05 xleroy Exp $ */
+/* $Id: config.h 9117 2008-11-02 14:30:05Z xleroy $ */
 
 #ifndef CAML_CONFIG_H
 #define CAML_CONFIG_H
 
-#define ARCH_SIXTYFOUR
+#undef ARCH_SIXTYFOUR
 #define SIZEOF_INT 4
-#define SIZEOF_LONG 8
-#define SIZEOF_PTR 8
+#define SIZEOF_LONG 4
+#define SIZEOF_PTR 4
 #define SIZEOF_SHORT 2
-#define ARCH_INT64_TYPE long
-#define ARCH_UINT64_TYPE unsigned long
-#define ARCH_INT64_PRINTF_FORMAT "l"
+#define ARCH_INT64_TYPE long long
+#define ARCH_UINT64_TYPE unsigned long long
+#define ARCH_INT64_PRINTF_FORMAT "ll"
 #define ARCH_BIG_ENDIAN
-#undef ARCH_ALIGN_DOUBLE
-#undef ARCH_ALIGN_INT64
+#define ARCH_ALIGN_DOUBLE
+#define ARCH_ALIGN_INT64
 #undef NONSTANDARD_DIV_MOD
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/local/lib/ocaml"
