@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: filename.ml,v 1.37.2.2 2006/01/05 19:19:52 doligez Exp $ *)
+(* $Id: filename.ml 9339 2009-09-16 14:24:11Z xclerc $ *)
 
 let generic_quote quotequote s =
   let l = String.length s in
@@ -97,15 +97,25 @@ module Win32 = struct
     let l = String.length s in
     let b = Buffer.create (l + 20) in
     Buffer.add_char b '\"';
-    for i = 0 to l - 1 do
+    let rec loop i =
+      if i = l then Buffer.add_char b '\"' else
       match s.[i] with
-        '\"' -> Buffer.add_string b "\\\""
-      | '\\' -> if i + 1 = l then Buffer.add_string b "\\\\"
-                else if s.[i + 1] = '\"' then Buffer.add_string b "\\\\\\\""
-                else Buffer.add_char b '\\'
-      |   c  -> Buffer.add_char b c
-    done;
-    Buffer.add_char b '\"';
+      | '\"' -> loop_bs 0 i;
+      | '\\' -> loop_bs 0 i;
+      | c    -> Buffer.add_char b c; loop (i+1);
+    and loop_bs n i =
+      if i = l then begin
+        Buffer.add_char b '\"';
+        add_bs n;
+      end else begin
+        match s.[i] with
+        | '\"' -> add_bs (2*n+1); Buffer.add_char b '\"'; loop (i+1);
+        | '\\' -> loop_bs (n+1) (i+1);
+        | c    -> add_bs n; loop i
+      end
+    and add_bs n = for j = 1 to n do Buffer.add_char b '\\'; done
+    in
+    loop 0;
     Buffer.contents b
   let has_drive s =
     let is_letter = function
@@ -184,14 +194,14 @@ external close_desc: int -> unit = "caml_sys_close"
 
 let prng = Random.State.make_self_init ();;
 
-let temp_file_name prefix suffix =
+let temp_file_name temp_dir prefix suffix =
   let rnd = (Random.State.bits prng) land 0xFFFFFF in
-  concat temp_dir_name (Printf.sprintf "%s%06x%s" prefix rnd suffix)
+  concat temp_dir (Printf.sprintf "%s%06x%s" prefix rnd suffix)
 ;;
 
-let temp_file prefix suffix =
+let temp_file ?(temp_dir=temp_dir_name) prefix suffix =
   let rec try_name counter =
-    let name = temp_file_name prefix suffix in
+    let name = temp_file_name temp_dir prefix suffix in
     try
       close_desc(open_desc name [Open_wronly; Open_creat; Open_excl] 0o600);
       name
@@ -199,9 +209,9 @@ let temp_file prefix suffix =
       if counter >= 1000 then raise e else try_name (counter + 1)
   in try_name 0
 
-let open_temp_file ?(mode = [Open_text]) prefix suffix =
+let open_temp_file ?(mode = [Open_text]) ?(temp_dir=temp_dir_name) prefix suffix =
   let rec try_name counter =
-    let name = temp_file_name prefix suffix in
+    let name = temp_file_name temp_dir prefix suffix in
     try
       (name,
        open_out_gen (Open_wronly::Open_creat::Open_excl::mode) 0o600 name)
