@@ -14,7 +14,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: protocol.mli,v 1.11 2002/05/03 12:56:59 furuse Exp $ *)
+(* $Id: protocol.mli 7283 2005-12-21 05:29:08Z garrigue $ *)
 
 open Widget
 
@@ -73,6 +73,15 @@ val finalizeTk : unit -> unit
        called when you call [Pervasives.exit ()] *)
 
 val mainLoop : unit -> unit
+    (* Start the event loop *)
+
+type event_flag =
+  DONT_WAIT | X_EVENTS | FILE_EVENTS | TIMER_EVENTS | IDLE_EVENTS | ALL_EVENTS
+val do_one_event : event_flag list -> bool
+    (* Process a single event *)
+val do_pending : unit -> unit
+    (* Process all pending events, without waiting.
+       This lets you use Tk from the toplevel, for instance. *)
 
 
 (* Direct evaluation of tcl code *)
